@@ -34,10 +34,3 @@ def getRates():
     except Exception as e:
         print(e)
         return None
-
-# Make a class named Exchange, it has a simple constructor function
-
-
-class ExchangeRON:
-    def __init__(self):
-        self.rates = getRates()
